@@ -24,13 +24,16 @@ def checkAndUpdate(driver_path:str):
         driver_version = _matchChromeVersion(driver+" --version")
         if chrome_version == driver_version:
             return os.path.realpath(driver)
-    # 下载对应版本驱动
-    ''' 
-        1. 删除原先driver
-        2. 下载对应驱动
-    '''
-    os.unlink(driver)
+        # 下载对应版本驱动
+        ''' 
+            1. 删除原先driver
+            2. 下载对应驱动
+        '''
+        os.unlink(driver)
     _downLoadDriver(chrome_version,driver_path)
+    # 赋执行权限
+    os.chmod(driver,755)
+    # _driverRunableConfig(driver)
 
     
 
@@ -126,4 +129,10 @@ def _downLoadDriver(version, save_d):
     zFile = zipfile.ZipFile(temp_driver_zip, 'r')
     zFile.extract("chromedriver",save_d)
     zFile.close()
-    shutil.rmtree(temp_path)
\ No newline at end of file
+    shutil.rmtree(temp_path)
+
+def _driverRunableConfig(driver_path:str):
+    # 苹果电脑
+    if platform.system() == "Darwin":
+        #  需要过验证
+        subprocess.Popen("xattr -d com.apple.quarantine "+driver_path,shell=True)
\ No newline at end of file
